@@ -4,10 +4,13 @@ __all__ = ['w56_download', 'w56_download_by_id']
 
 from ..common import *
 
+from .sohu import sohu_download
+
 import json
 
 def w56_download_by_id(id, title = None, output_dir = '.', merge = True, info_only = False):
-    info = json.loads(get_html('http://vxml.56.com/json/%s/?src=site' % id))['info']
+    content = json.loads(get_html('http://vxml.56.com/json/%s/?src=site' % id))
+    info = content['info']
     title = title or info['Subject']
     assert title
     hd = info['hd']
@@ -24,6 +27,12 @@ def w56_download_by_id(id, title = None, output_dir = '.', merge = True, info_on
         download_urls([url], title, ext, size, output_dir = output_dir, merge = merge)
 
 def w56_download(url, output_dir = '.', merge = True, info_only = False, **kwargs):
+    content = get_content(url)
+    sohu_url = r1(r"url:\s*'([^']*)'", content)
+    if sohu_url:
+        sohu_download(sohu_url, output_dir, merge=merge, info_only=info_only, **kwargs)
+        return
+
     id = r1(r'http://www.56.com/u\d+/v_(\w+).html', url) or \
          r1(r'http://www.56.com/.*vid-(\w+).html', url)
     w56_download_by_id(id, output_dir = output_dir, merge = merge, info_only = info_only)
