@@ -157,34 +157,22 @@ class YouTube(VideoExtractor):
             log.wtf('[Failed] Unsupported URL pattern.')
 
         video_page = get_content('https://www.youtube.com/playlist?list=%s' % playlist_id)
-        from html.parser import HTMLParser
-        videos = sorted([HTMLParser().unescape(video)
-                         for video in re.findall(r'<a href="(/watch\?[^"]+)"', video_page)
-                         if parse_query_param(video, 'index')],
-                        key=lambda video: parse_query_param(video, 'index'))
+        ytInitialData = json.loads(match1(video_page, r'window\["ytInitialData"\]\s*=\s*(.+);'))
 
-        # Parse browse_ajax page for more videos to load
-        load_more_href = match1(video_page, r'data-uix-load-more-href="([^"]+)"')
-        while load_more_href:
-            browse_ajax = get_content('https://www.youtube.com/%s' % load_more_href)
-            browse_data = json.loads(browse_ajax)
-            load_more_widget_html = browse_data['load_more_widget_html']
-            content_html = browse_data['content_html']
-            vs = set(re.findall(r'href="(/watch\?[^"]+)"', content_html))
-            videos += sorted([HTMLParser().unescape(video)
-                              for video in list(vs)
-                              if parse_query_param(video, 'index')])
-            load_more_href = match1(load_more_widget_html, r'data-uix-load-more-href="([^"]+)"')
+        tab0 = ytInitialData['contents']['twoColumnBrowseResultsRenderer']['tabs'][0]
+        itemSection0 = tab0['tabRenderer']['content']['sectionListRenderer']['contents'][0]
+        playlistVideoList0 = itemSection0['itemSectionRenderer']['contents'][0]
+        videos = playlistVideoList0['playlistVideoListRenderer']['contents']
 
         self.title = re.search(r'<meta name="title" content="([^"]+)"', video_page).group(1)
         self.p_playlist()
-        for video in videos:
-            vid = parse_query_param(video, 'v')
-            index = parse_query_param(video, 'index')
+        for index, video in enumerate(videos, 1):
+            vid = video['playlistVideoRenderer']['videoId']
             try:
                 self.__class__().download_by_url(self.__class__.get_url_from_vid(vid), index=index, **kwargs)
             except:
                 pass
+        # FIXME: show DASH stream sizes (by default) for playlist videos
 
     def prepare(self, **kwargs):
         assert self.url or self.vid
